<?php
/**
 * Created by PhpStorm.
 * User: Alexander
 * Date: 31.01.2017
 * Time: 10:21
 */

namespace UBRIR;

use MongoDB\BSON\Type;

include_once 'UBRIR_TypeEnums.php';
include_once 'UBRIR_Helpers.php';
include_once 'UBRIR_ResultViewer.php';
include_once 'UBRIR_DataContainer.php';
include_once 'UBRIR_CMS_Payment.php';
include_once 'UBRIR_ServerConnector.php';

class Diafan extends CMS_Payment
{
    const DB_PREFIX = 'diafan_';

    protected $ModuleRootDir;
    private $_diafanCore;

    function __construct()
    {
        $this->workMode = 'TEST';
        $this->ModuleRootDir = realpath(dirname(__FILE__) . '/../') . '/';

        $this->logDir = $this->ModuleRootDir . 'logs/';
        $this->logFile = $this->logDir . 'ubrr.log';

        $this->useLogs = true; //По умолчанию для тестового режиме
    }

    public function ConnectDiafanCore($diafanCore = null)
    {
        $this->_diafanCore = $diafanCore;

        return $this;
    }

    /**
     * @param $paymentData
     * @param string $successMessage
     * @param array $extraData
     * @param $continueLink
     */
    public function ShowPaymentSuccess($message = '', ResultViewer $resultData = null, $pay_module_name = 'cart')
    {
        $continueLink = '/';
        if (!empty($pay_module_name)) {
            $order_rew = \DB::query_result("SELECT rewrite FROM {rewrite} WHERE module_name='site' AND trash='0' AND element_type='element' AND element_id IN (SELECT id FROM {site} WHERE module_name='%s' AND [act]='1' AND trash='0')", $pay_module_name);
            $continueLink = 'http' . (IS_HTTPS ? "s" : '') . '://' . getenv("HTTP_HOST") . '/' . (REVATIVE_PATH ? REVATIVE_PATH . '/' : '') . $order_rew . '/step3/';
        }

        if ($resultData == null)
            $resultData = new ResultViewer();

        $result = $resultData
            ->SetSuccessMessage($message)
            ->SetContinueLink($continueLink)
            ->ViewData();

        echo $this->_diafanCore->_tpl->get('payment_status', 'ubrr', $result);
    }

    public function ShowError($errorMessage = '', ResultViewer $resultData = null, $pay_module_name = 'cart')
    {
        $continueLink = '/';
        if (!empty($pay_module_name)) {
            $order_rew = \DB::query_result("SELECT rewrite FROM {rewrite} WHERE module_name='site' AND trash='0' AND element_type='element' AND element_id IN (SELECT id FROM {site} WHERE module_name='%s' AND [act]='1' AND trash='0')", $pay_module_name);
            $continueLink = 'http' . (IS_HTTPS ? "s" : '') . '://' . getenv("HTTP_HOST") . '/' . (REVATIVE_PATH ? REVATIVE_PATH . '/' : '') . $order_rew . '/step4/';
        }

        if ($resultData == null)
            $resultData = new ResultViewer();

        $result = $resultData
            ->SetFailureMessage($errorMessage)
            ->SetContinueLink($continueLink)
            ->ViewData();

        echo $this->_diafanCore->_tpl->get('payment_status', 'ubrr', $result);
    }

    public function CleanDebugLog()
    {
        if (file_exists($this->logFile)) {
            return unlink($this->logFile);
        }
        return false;
    }

    public function GetDebugLogText()
    {
        if (file_exists($this->logFile)) {
            //TODO: Тут стоит читать с конца + явно только часть, длинный лог пихать в память смысла нет
            return file_get_contents($this->logFile);
        }
    }

    public function ServerConnectionConfigLoadFromDB()
    {
        $payment = \DB::query_fetch_array("SELECT payment, [text], params FROM {payment} WHERE payment='%s' ORDER BY id DESC LIMIT 1", 'ubrr');
        if ($payment !== null) {
            $params = unserialize($payment["params"]);
            $shopId = $params['ubrr_client_id'];
            $privatePassword = $params['ubrr_certificate_pass'];

            if (isset($params['ubrr_test']) && intval($params['ubrr_test']) == 1) {
                $this->workMode = 'TEST';
            } else {
                $this->workMode = 'NORMAL';
            }

            $this->ServerConnectionConfig($shopId, $privatePassword);
        }
    }

    public static function GetOrderIdByPayId($payId)
    {
        $payId = intval($payId);
        if ($payId > 0) {
            $paymentHistoryRow = \DB::query_fetch_array("SELECT id AS pay_id, element_id AS order_id FROM {payment_history} WHERE id=%d LIMIT 1", $payId);
            if ($paymentHistoryRow !== null) {
                $orderId = intval($paymentHistoryRow['order_id']);
                return $orderId;
            }
        }

        return false;
    }

    /**
     * Проверяем что все необходимые поля для подготовки оплаты переданы и можно формировать XML к отправке
     * [Метод пишет в лог, начинает и заканчивает]
     */
    public function PrepareToPay()
    {
        //Проверка на заполненность всех необходимых полей
        $Amount = $this->getAmount();
        $Merchant = $this->getShopId();

        $ApproveURL = $this->getApproveURL();
        $CancelURL = $this->getCancelURL();
        $DeclineURL = $this->getDeclineURL();

        $serverResponse = ServerConnector::PrepareToPay($this);

        $this->Log('[END]');
        return $serverResponse;
    }

    //Заполнение необходимых параметров и затем попытка передачи
    public function SetupAndPrepareToPay($orderId, $orderAmount, $approveCallbackURL, $cancelCallbackURL = '', $declineCallbackURL = '')
    {
        $this->orderId = $orderId;
        $this->orderAmount = $orderAmount;

        if (empty($cancelCallbackURL))
            $cancelCallbackURL = $approveCallbackURL;

        if (empty($declineCallbackURL))
            $declineCallbackURL = $approveCallbackURL;

        $this->approveUrl = $approveCallbackURL;
        $this->cancelUrl = $cancelCallbackURL;
        $this->declineUrl = $declineCallbackURL;

        return $this->PrepareToPay();
    }

    public function GetOrderInformation()
    {
        //Проверка на заполненность всех необходимых полей
        $TWPG_OrderId = $this->getTWPG_OrderId();
        $TWPG_SessionId = $this->getTWPG_SessionId();

        $serverResponse = ServerConnector::GetOrderInformation($this);

        if ($serverResponse->isSuccess()) {
            $orderInfo = $serverResponse->XMLNestedFields->Response->Order->row;

            $parsedResponse['ID'] = intval($orderInfo->id[0]);
            $parsedResponse['SessionID'] = strval($orderInfo->SessionID[0]);
            $parsedResponse['CreateDate'] = strval($orderInfo->createDate[0]);
            $parsedResponse['LastUpdateDate'] = strval($orderInfo->lastUpdateDate[0]);
            $parsedResponse['PayDate'] = strval($orderInfo->payDate[0]);
            $parsedResponse['MerchantID'] = strval($orderInfo->MerchantID[0]);
            $parsedResponse['Amount'] = floatval($orderInfo->Amount[0]) / 100;
            $parsedResponse['Currency'] = strval($orderInfo->Currency[0]);
            $parsedResponse['OrderLanguage'] = strval($orderInfo->OrderLanguage[0]);
            $parsedResponse['Description'] = strval($orderInfo->Description[0]);
            $parsedResponse['ApproveURL'] = strval($orderInfo->ApproveURL[0]);
            $parsedResponse['CancelURL'] = strval($orderInfo->CancelURL[0]);
            $parsedResponse['DeclineURL'] = strval($orderInfo->DeclineURL[0]);
            $parsedResponse['OrderStatus'] = TypeEnums::GetLabel_OrderStatus($orderInfo->Orderstatus[0]);
            $parsedResponse['RefundAmount'] = strval($orderInfo->RefundAmount[0]);
            $parsedResponse['RefundCurrency'] = strval($orderInfo->RefundCurrency[0]);
            $parsedResponse['ExtSystemProcess'] = strval($orderInfo->ExtSystemProcess[0]);
            $parsedResponse['OrderType'] = TypeEnums::GetLabel_OrderType($orderInfo->OrderType[0]);
            $parsedResponse['Fee'] = strval($orderInfo->Fee[0]);
            $parsedResponse['RefundDate'] = strval($orderInfo->RefundDate[0]);
            $parsedResponse['TWODate'] = strval($orderInfo->TWODate[0]);
            $parsedResponse['TWOTime'] = strval($orderInfo->TWOTime[0]);

            $parsedResponse['Operations'] = Array();
            $arOperations = $orderInfo->OrderOperations->row;
            foreach ($arOperations as $operation) {
                $formattedOperation = Array(
                    'PackageId' => strval($operation->PackageId[0]),
                    'CreateDate' => strval($operation->createDate[0]),
                    'MerchantID' => strval($operation->MerchantID[0]),
                    'OperType' => strval($operation->OperType[0]),
                    'OperName' => TypeEnums::GetLabel_OperName($operation->OperName[0]),
                    'OrderId' => strval($operation->OrderId[0]),
                    'Amount' => floatval($operation->Amount[0]) / 100,
                    'Currency' => strval($operation->Currency[0]),
                    'Approval' => strval($operation->Approval[0]),
                    'TwoId' => strval($operation->twoId[0]),
                );

                $parsedResponse['Operations'][] = $formattedOperation;
            }

            $serverResponse->SetParsedResponse($parsedResponse, 'orderinfo');
        }


        $this->Log('[END]');
        return $serverResponse;
    }

    public function SetupAndGetOrderInformation($TWPG_OrderId, $SessionId)
    {
        $this->ubrrOrderId = $TWPG_OrderId;
        $this->ubrrSessionId = $SessionId;

        return $this->GetOrderInformation();
    }

    public function SetupAndCheckOrderStatus($TWPG_OrderId, $SessionId)
    {
        $this->ubrrOrderId = $TWPG_OrderId;
        $this->ubrrSessionId = $SessionId;

        return $this->CheckOrderStatus();
    }

    public function CheckOrderStatus()
    {
        //Проверка на заполненность всех необходимых полей
        $TWPG_OrderId = $this->getTWPG_OrderId();
        $TWPG_SessionId = $this->getTWPG_SessionId();

        $serverResponse = ServerConnector::GetOrderStatus($this);

        $this->Log('[END]');
        return $serverResponse;
    }

    public static function SaveTWPGOrder($payId, $orderId, $TWPG_OrderId, $SessionId)
    {
        $sql = "INSERT INTO `" . self::DB_PREFIX . "ubrr_twpg_orders` (`diafan_order_id`, `diafan_pay_id`, `twpg_order_id`, `twpg_session_id`) 
                VALUES ('" . $orderId . "','" . $payId . "', '" . $TWPG_OrderId . "', '" . $SessionId . "') 
                ON DUPLICATE KEY UPDATE `diafan_order_id`='" . $orderId . "', `diafan_pay_id`='" . $payId . "', `twpg_order_id`='" . $TWPG_OrderId . "', `twpg_session_id`='" . $SessionId . "'";

        $dbResult = \DB::query($sql);
        return $dbResult;
    }

    public static function GetTWPGDataByUBRIROrderID($TWPG_OrderId)
    {
        $sql = 'SELECT * FROM `' . self::DB_PREFIX . 'ubrr_twpg_orders` WHERE `twpg_order_id`=' . $TWPG_OrderId;
        $rows = \DB::query_fetch_all($sql);

        if (count($rows) >= 1) {
            $row = $rows[0];

            $orderID = $row['diafan_order_id'];
            $payID = $row['diafan_pay_id'];
            $TWPG_OrderId = $row['twpg_order_id'];
            $SessionId = $row['twpg_session_id'];

            return array(
                'order_id' => $orderID,
                'pay_id' => $payID,
                'twpg_order_id' => $TWPG_OrderId,
                'twpg_session_id' => $SessionId
            );
        }
        return false;
    }

    public static function GetTWPGDataByPayId($payId)
    {
        $sql = 'SELECT * FROM `' . self::DB_PREFIX . 'ubrr_twpg_orders` WHERE `diafan_pay_id`=' . $payId;
        $rows = \DB::query_fetch_all($sql);

        if (count($rows) >= 1) {
            $row = $rows[0];

            $TWPG_OrderId = $row ['twpg_order_id'];
            $SessionId = $row ['twpg_session_id'];
            return array(
                'twpg_order_id' => $TWPG_OrderId,
                'twpg_session_id' => $SessionId
            );
        }
        return false;
    }
}