<?php
/**
 * Created by PhpStorm.
 * User: Alexander
 * Date: 07.02.2017
 * Time: 11:56
 */

namespace UBRIR;

class ResultViewer
{
    private $_PaymentSuccess = false;

    private $orderStatusText = 'Ошибка полученния данных';
    private $title = 'УБРиР: Ошибка';
    private $continueLink = '/';
    private $extraMessages = Array();
    private $lang = Array('language' => 'ru', 'direction' => '');
    private $meta = Array('base' => '');

    private $paymentAmount = 0;
    private $orderId = 0;
    private $paymentTime = null;
    private $paymentDetails = Array();

    function __construct()
    {
        if (!empty($_SERVER['HTTPS'])) {
            $meta['base'] = 'http://' . $_SERVER['SERVER_NAME'] . '/';
        } else {
            $meta['base'] = 'https://' . $_SERVER['SERVER_NAME'] . '/';
        }
    }

    public function SetLangParam($langParamName, $value)
    {
        if (isset($this->lang[$langParamName]))
            $this->lang[$langParamName] = $value;

        return $this;
    }

    public function SetMetaParam($metaParamName, $value)
    {
        if (isset($this->meta[$metaParamName]))
            $this->meta[$metaParamName] = $value;

        return $this;
    }

    public function SetMessageBaseOnResponse(DataContainer $responseData)
    {
        $orderStatus = $responseData->getFieldValue('OrderStatus');
        $responseDescription = $responseData->getFieldValue('ResponseDescription');
        switch ($orderStatus) {
            case TypeEnums::OrderStatus_DECLINED: {
                if (!empty($responseDescription)) {
                    if ($orderStatus == TypeEnums::OrderStatus_DECLINED)
                        $responseDescription = 'Платеж отклонен: ' . $responseDescription;
                } else {
                    $responseDescription = 'Платеж отклонен банком';
                }
            }
                break;
            case TypeEnums::OrderStatus_CANCELED: {
                $responseDescription = 'Платеж отменен пользователем';
            };
                break;
        }

        if (!empty($responseDescription)) {
            $this->SetMessage($responseDescription);
        }

        return $this;
    }

    public function SetFailureMessage($errorMessage)
    {
        $this->_PaymentSuccess = false;
        if (!empty($errorMessage)) {
            $this->SetMessage($errorMessage);
        }

        return $this;
    }

    public function SetSuccessMessage($message)
    {
        $this->_PaymentSuccess = true;
        if (!empty($message)) {
            $this->SetMessage($message);
        }

        return $this;
    }

    public function SetPaymentTime($strPaymentTime)
    {
        $this->paymentTime = $strPaymentTime;

        return $this;
    }

    public function SetPaymentAmount($strAmount)
    {
        $this->paymentAmount = $strAmount;
    }

    public function SetMessage($message)
    {
        $this->orderStatusText = $message;
        $this->title = 'УБРиР: ' . $message;

        return $this;
    }

    public function SetContinueLink($continueLink)
    {
        $this->continueLink = $continueLink;

        return $this;
    }

    public function ClearPaymentDetails()
    {
        $this->paymentDetails = Array();
        return $this;
    }

    public function AddPaymentDetail($detailTitle, $detailValue)
    {
        $this->paymentDetails[$detailTitle] = $detailValue;
        return $this;
    }

    public function ClearExtraMessages()
    {
        $this->extraMessages = Array();
        return $this;
    }

    public function AddExtraMessage($message, $messageCode = '')
    {
        if (empty($messageCode))
            array_push($this->extraMessages, $message);
        else
            $this->extraMessages[$messageCode] = $message;

        return $this;
    }

    public function SetCardPAN($cardPAN)
    {
        $this->AddPaymentDetail('Карта', $cardPAN);

        return $this;
    }

    public function SetCardOwner($cardOwner)
    {
        $this->AddPaymentDetail('Владелец карты', $cardOwner);

        return $this;
    }

    public function SetShopOrderId($OrderId)
    {
        $this->orderId = $OrderId;
        return $this;
    }

    public function SetTWPG_OrderId($TWPG_OrderId)
    {
        $this->AddPaymentDetail('Номер транзакции', $TWPG_OrderId);
        return $this;
    }

    public function ViewData()
    {
        $resultData = Array();
        if ($this->_PaymentSuccess) {
            $resultData['paymentStatusClass'] = 'payment__success';
        } else {
            $resultData['paymentStatusClass'] = 'payment__failure';
        }

        $resultData['lang_language'] = $this->lang['language'];
        $resultData['meta'] = $this->meta;
        $resultData['orderStatusText'] = $this->orderStatusText;
        $resultData['title'] = $this->title;
        $resultData['continue_link'] = $this->continueLink;
        $resultData['extra_messages'] = $this->extraMessages;

        if (!empty($this->paymentAmount))
            $resultData['paymentAmount'] = $this->paymentAmount;
        else
            $resultData['paymentAmount'] = '';

        if ($this->orderId > 0)
            $resultData['OrderID'] = $this->orderId;
        else
            $resultData['OrderID'] = '';

        if (!empty($this->paymentTime))
            $resultData['paymentDateTime'] = $this->paymentTime;
        else
            $resultData['paymentDateTime'] = '';

        $resultData['paymentDetails'] = $this->paymentDetails;

        return $resultData;
    }

}